summaryrefslogtreecommitdiffstats
path: root/sys/netinet/sctp_structs.h
diff options
context:
space:
mode:
authorrrs <rrs@FreeBSD.org>2006-12-14 17:02:55 +0000
committerrrs <rrs@FreeBSD.org>2006-12-14 17:02:55 +0000
commit3de80805ffbf0e87c0ff547698814193edb8bd14 (patch)
tree940611c208a2462c47614c0688becd97244ad6fe /sys/netinet/sctp_structs.h
parentd398e83b8a941f854ec49ad93c3694c17b0f8e88 (diff)
downloadFreeBSD-src-3de80805ffbf0e87c0ff547698814193edb8bd14.zip
FreeBSD-src-3de80805ffbf0e87c0ff547698814193edb8bd14.tar.gz
1) Fixes on a number of different collision case LOR's.
2) Fix all "magic numbers" to be constants. 3) A collision case that would generate two associations to the same peer due to a missing lock is fixed. 4) Added tracking of where timers are stopped. Approved by: gnn
Diffstat (limited to 'sys/netinet/sctp_structs.h')
-rw-r--r--sys/netinet/sctp_structs.h13
1 files changed, 10 insertions, 3 deletions
diff --git a/sys/netinet/sctp_structs.h b/sys/netinet/sctp_structs.h
index 6472c2f..9f4e9d0 100644
--- a/sys/netinet/sctp_structs.h
+++ b/sys/netinet/sctp_structs.h
@@ -64,6 +64,7 @@ struct sctp_timer {
/* for sanity checking */
void *self;
uint32_t ticks;
+ uint32_t stopped_from;
};
struct sctp_nonpad_sndrcvinfo {
@@ -78,6 +79,13 @@ struct sctp_nonpad_sndrcvinfo {
sctp_assoc_t sinfo_assoc_id;
};
+struct sctp_foo_stuff {
+ struct sctp_inpcb *inp;
+ uint32_t lineno;
+ uint32_t ticks;
+ int updown;
+};
+
/*
* This is the information we track on each interface that we know about from
@@ -284,7 +292,7 @@ struct sctp_data_chunkrec {
struct timeval timetodrop; /* time we drop it from queue */
uint8_t doing_fast_retransmit;
uint8_t rcv_flags; /* flags pulled from data chunk on inbound for
* outbound holds sending flags. */
uint8_t state_flags;
uint8_t chunk_was_revoked;
};
@@ -395,12 +403,11 @@ struct sctp_stream_queue_pending {
uint16_t sinfo_flags;
uint16_t stream;
uint16_t strseq;
+ uint16_t act_flags;
uint8_t msg_is_complete;
uint8_t some_taken;
uint8_t addr_over;
- uint8_t act_flags;
uint8_t pr_sctp_on;
- uint8_t resv;
};
/*
OpenPOWER on IntegriCloud
@@ -284,7 +292,7 @@ struct sctp_data_chunkrec {
uint8_t doing_fast_retransmit;
uint8_t rcv_flags; /* flags pulled from data chunk on inbound for
- * outbound holds sending flags. */
+ * outbound holds sending flags for PR-SCTP. */
uint8_t state_flags;
uint8_t chunk_was_revoked;